@@ -19,7 +19,7 @@ from cmsplugin_zinnia.models import SelectedEntriesPlugin
 
 class CMSLatestEntriesPlugin(CMSPluginBase):
     """Plugin for including the latest entries filtered"""
-    module = _('entries')
+    module = 'Zinnia'
     model = LatestEntriesPlugin
     name = _('Latest entries')
     render_template = 'cmsplugin_zinnia/entry_list.html'
@@ -27,11 +27,9 @@ class CMSLatestEntriesPlugin(CMSPluginBase):
     fieldsets = (
         (None, {'fields': ('number_of_entries',
                            'template_to_render')}),
-        (_('Sorting'), {'fields': ('categories',
-                                   'authors',
-                                   'tags'),
-                        'classes': ('collapse',)}),
-        (_('Advanced'), {'fields': ('subcategories',)}))
+        (_('Filters'), {'fields': (('categories', 'subcategories'),
+                                   'authors', 'tags'),
+                        'classes': ('collapse',)}),)
     text_enabled = True
 
     def formfield_for_manytomany(self, db_field, request, **kwargs):
@@ -61,7 +59,9 @@ class CMSLatestEntriesPlugin(CMSPluginBase):
             entries = TaggedItem.objects.get_union_by_model(
                 entries, instance.tags.all())
 
-        entries = entries.distinct()[:instance.number_of_entries]
+        entries = entries.distinct()
+        if instance.number_of_entries:
+            entries = entries[:instance.number_of_entries]
         context.update({'entries': entries,
                         'object': instance,
                         'placeholder': placeholder})
@@ -74,7 +74,7 @@ class CMSLatestEntriesPlugin(CMSPluginBase):
 
 class CMSSelectedEntriesPlugin(CMSPluginBase):
     """Plugin for including a selection of entries"""
-    module = _('entries')
+    module = 'Zinnia'
     model = SelectedEntriesPlugin
     name = _('Selected entries')
     render_template = 'cmsplugin_zinnia/entry_list.html'
@@ -96,7 +96,7 @@ class CMSSelectedEntriesPlugin(CMSPluginBase):
 
 class CMSRandomEntriesPlugin(CMSPluginBase):
     """Plugin for including random entries"""
-    module = _('entries')
+    module = 'Zinnia'
     model = RandomEntriesPlugin
     name = _('Random entries')
     render_template = 'cmsplugin_zinnia/random_entries.html'
@@ -118,8 +118,8 @@ class CMSRandomEntriesPlugin(CMSPluginBase):
 
 class CMSSearchPlugin(CMSPluginBase):
     """Plugins for including a Zinnia's search form"""
+    module = 'Zinnia'
     model = CMSPlugin
-    module = _('entries')
     name = _('Entries search form')
     render_template = 'cmsplugin_zinnia/search_form.html'
     text_enabled = True
@@ -127,6 +127,30 @@ class CMSSearchPlugin(CMSPluginBase):
     def render(self, context, instance, placeholder):
         return context
 
+    def icon_alt(self, instance):
+        """Alternative text of the plugin"""
+        return unicode(self.name)
+
+    def icon_src(self, instance):
+        """Icon source of the plugin"""
+        return settings.STATIC_URL + u'cmsplugin_zinnia/img/plugin.png'
+
+
+class CMSToolsPlugin(CMSPluginBase):
+    """Plugins for including tool links for Zinnia"""
+    module = 'Zinnia'
+    model = CMSPlugin
+    name = _('Administration tools')
+    render_template = 'cmsplugin_zinnia/tools.html'
+    text_enabled = True
+
+    def render(self, context, instance, placeholder):
+        return context
+
+    def icon_alt(self, instance):
+        """Alternative text of the plugin"""
+        return unicode(self.name)
+
     def icon_src(self, instance):
         """Icon source of the plugin"""
         return settings.STATIC_URL + u'cmsplugin_zinnia/img/plugin.png'
@@ -136,3 +160,4 @@ plugin_pool.register_plugin(CMSLatestEntriesPlugin)
 plugin_pool.register_plugin(CMSSelectedEntriesPlugin)
 plugin_pool.register_plugin(CMSRandomEntriesPlugin)
 plugin_pool.register_plugin(CMSSearchPlugin)
+plugin_pool.register_plugin(CMSToolsPlugin)
